==> v_alpha4.0.zip: tizenbuildtools/desktop/downloadAndBuildAll.sh <==
#!/bin/bash
# Copyright (C) 2013 Tomasz Olszak <olszak.tomasz@gmail.com>
# All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:

# 1. Redistributions of source code must retain the copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products 
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

set -e

CURRENT_DIR=$(pwd)

SCRIPT_DIR=$(dirname $0)

cd $SCRIPT_DIR

function usage {
    echo -e "\n"
    echo "Script for Qt for tizen compilation. "
    echo "Set Parameters or environment variables with absolute paths"
    echo ""
    echo "Usage:"
    echo "sudo [MAKE_THREADS=numberOfCPUCores] [QT5SRCDIR=Qt5SrcPath] [INSTALLDIR=QtInstallPrefix] ./downloadAndBuildAll.sh"
    echo ""
    echo "QT5SRCDIR - directory with qt5 sources"
    echo "INSTALLDIR - here qmake and other host binaries will be installed"
    echo "If corresponding environment variables are set then script can be invoked without parameters"
    echo "set MAKE_THREADS environment variable to number of your CPU cores to fast up compilation step"    
    echo ""
    cd $CURRENT_DIR
    exit;
}

if [ "$1" == "-h" -o "$1" == "--help" ]; then
    usage
fi

if [ "$QT5SRCDIR" == "" ]; then
    QT5SRCDIR=$PWD/qt5.gitorious
    echo "Setting QT5SRCDIR to $QT5SRCDIR"
fi

if [ "$INSTALLDIR" == "" ]; then
    INSTALLDIR=$PWD/qt5hostInstall
    echo "Setting INSTALLDIR to $INSTALLDIR"
fi

if [ "$QT5SRCDIR" == "$PWD/qt5.gitorious" ]; then
    if [ ! -d qt5.gitorious ]; then
        mkdir qt5.gitorious
    else
        echo "Looks like qt5.gitorious directory exists"	
    fi;
    cd qt5.gitorious
    $PWD/../../scripts/clone_or_update_tizen_repos
    cd ..
fi;

mkdir -p buildQt5/qtbase
cd buildQt5/qtbase

echo "================================================="
echo "Configuration:"
echo "QT5SRCDIR=$QT5SRCDIR"
echo "INSTALLDIR=$INSTALLDIR"
echo "================================================="


$QT5SRCDIR/qtbase/configure --disable-static -confirm-license -opensource -no-warnings-are-errors -prefix $INSTALLDIR -no-sql-ibase -no-sql-mysql -no-sql-odbc -no-sql-psql -plugin-sql-sqlite -no-sql-sqlite2 -no-sql-tds -nomake tests -nomake examples -verbose

MAKE_ARGS=""

if [ "$MAKE_THREADS" != "" ]; then
    echo "setting make thread"
    MAKE_ARGS="-j $MAKE_THREADS"
fi
echo =======================
echo building qtbase: make $MAKE_ARGS
echo =======================

make $MAKE_ARGS
echo Installing qtbase: make install $MAKE_ARGS
make install $MAKE_ARGS
cd ..

#without qtbase

parts="qtxmlpatterns qtgraphicaleffects qtimageformats qtdeclarative qtquickcontrols qtquickcontrols-tizen qtsensors qttools"

for repo in $parts; do
    echo =======================
    echo building $repo: make $MAKE_ARGS
    echo =======================    
    mkdir -p $repo
    cd $repo
    $INSTALLDIR/bin/qmake $QT5SRCDIR/$repo
    make $MAKE_ARGS
    echo Installing qtbase: make install $MAKE_ARGS
    make install $MAKE_ARGS
    cd ..            
done

cd $CURRENT_DIR

==> v_alpha6.1.zip: tizenbuildtools/desktop/downloadAndBuildAll.sh <==
#!/bin/bash
# Copyright (C) 2013 Tomasz Olszak <olszak.tomasz@gmail.com>
# All rights reserved.
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:

# 1. Redistributions of source code must retain the copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
# 3. The name of the author may not be used to endorse or promote products 
#    derived from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

set -e

CURRENT_DIR=$(pwd)

SCRIPT_DIR=$(dirname $0)

cd $SCRIPT_DIR

function usage {
    echo -e "\n"
    echo "Script for Qt for tizen compilation. "
    echo "Set Parameters or environment variables with absolute paths"
    echo ""
    echo "Usage:"
    echo "sudo [MAKE_THREADS=numberOfCPUCores] [QT5SRCDIR=Qt5SrcPath] [INSTALLDIR=QtInstallPrefix] ./downloadAndBuildAll.sh"
    echo ""
    echo "QT5SRCDIR - directory with qt5 sources"
    echo "INSTALLDIR - here qmake and other host binaries will be installed"
    echo "If corresponding environment variables are set then script can be invoked without parameters"
    echo "set MAKE_THREADS environment variable to number of your CPU cores to fast up compilation step"    
    echo ""
    cd $CURRENT_DIR
    exit;
}

if [ "$1" == "-h" -o "$1" == "--help" ]; then
    usage
fi

if [ "$QT5SRCDIR" == "" ]; then
    QT5SRCDIR=$PWD/qt5.gitorious
    echo "Setting QT5SRCDIR to $QT5SRCDIR"
fi

if [ "$INSTALLDIR" == "" ]; then
    INSTALLDIR=$PWD/qt5hostInstall
    echo "Setting INSTALLDIR to $INSTALLDIR"
fi

if [ "$QT5SRCDIR" == "$PWD/qt5.gitorious" ]; then
    if [ ! -d qt5.gitorious ]; then
        mkdir qt5.gitorious
    else
        echo "Looks like qt5.gitorious directory exists"	
    fi;
    cd qt5.gitorious
    $PWD/../../scripts/clone_or_update_tizen_repos
    cd ..
fi;

if [ "$INSTALLDIR" == "$PWD/qt5hostInstall" ]; then
    echo "removing default installation directory: $INSTALLDIR" 
    rm -rf $INSTALLDIR
fi

rm -rf buildQt5 qt5hostInstall

mkdir -p buildQt5/qtbase
cd buildQt5/qtbase

echo "================================================="
echo "Configuration:"
echo "QT5SRCDIR=$QT5SRCDIR"
echo "INSTALLDIR=$INSTALLDIR"
echo "================================================="


$QT5SRCDIR/qtbase/configure --disable-static -confirm-license -opensource -no-warnings-are-errors -prefix $INSTALLDIR -no-sql-ibase -no-sql-mysql -no-sql-odbc -no-sql-psql -plugin-sql-sqlite -no-sql-sqlite2 -no-sql-tds -nomake tests -nomake examples -verbose

MAKE_ARGS=""

if [ "$MAKE_THREADS" != "" ]; then
    echo "setting make thread"
    MAKE_ARGS="-j $MAKE_THREADS"
fi
echo =======================
echo building qtbase: make $MAKE_ARGS
echo =======================

make $MAKE_ARGS
echo Installing qtbase: make install $MAKE_ARGS
make install $MAKE_ARGS
cd ..

#without qtbase

parts="qtxmlpatterns qtgraphicaleffects qtimageformats qtdeclarative qtquickcontrols qtquickcontrols-tizen qtsensors qttools qtmultimedia"

for repo in $parts; do
    echo =======================
    echo building $repo: make $MAKE_ARGS
    echo =======================    
    mkdir -p $repo
    cd $repo
    $INSTALLDIR/bin/qmake $QT5SRCDIR/$repo
    make $MAKE_ARGS
    echo Installing qtbase: make install $MAKE_ARGS
    make install $MAKE_ARGS
    cd ..            
done

cd $CURRENT_DIR
